Changelog — Recipe 0.7.2 documentation

# Changelog

## 0.7.0 (2019-06-24)

- Support date ranges in configuration defined ingredients
- Add like, ilike, between in ingredients defined from config
- Better handling in automatic filters when Nones appear in lists
- Remove dirty flag
- Ingredients defined from config support safe division by default
- [ISSUE-37] Allow Dimension defined from config to be defined using buckets

## 0.6.2 (2019-06-11)

## 0.1.0 (2017-02-05)

- First release on PyPI.